.. _next-steps:

Next steps
~~~~~~~~~~

Your OpenStack environment now includes the zun_tempest_plugin service.

To add additional services, see
https://docs.openstack.org/project-install-guide/ocata/.
